feijoa.search.algorithms package
================================

Submodules
----------

feijoa.search.algorithms.algorithm module
-----------------------------------------

.. automodule:: feijoa.search.algorithms.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.algorithms.bayesian module
----------------------------------------

.. automodule:: feijoa.search.algorithms.bayesian
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.algorithms.genetic module
---------------------------------------

.. automodule:: feijoa.search.algorithms.genetic
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.algorithms.grid module
------------------------------------

.. automodule:: feijoa.search.algorithms.grid
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.algorithms.randomized module
------------------------------------------

.. automodule:: feijoa.search.algorithms.randomized
   :members:
   :undoc-members:
   :show-inheritance:

feijoa.search.algorithms.templatesearch module
----------------------------------------------

.. automodule:: feijoa.search.algorithms.templatesearch
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: feijoa.search.algorithms
   :members:
   :undoc-members:
   :show-inheritance:
